////////////////////////////////////////////////////////////////////////////////
//     
//    __                                ______
//   / /_______________  ____  ___     / ____/
//  / __/ ___/ ___/ __ \/ __ \/ _ \   /___ )  
// / /_(__  ) /__/ /_/ / /_/ /  __/  ____/ /  
// \__/____/\___/\____/ .___/\___/  /_____/   
//                   /_/                      
//     
/// \file primitives_internal.c
/// Definitions of internal primitives drawing functions
////////////////////////////////////////////////////////////////////////////////

#include "../include/tscope5/primitives_internal.h"
#include "../include/tscope5/system_internal.h"

#include <allegro5/allegro_primitives.h>

/// Is the primitives subsystem installed?
int  _ts5_is_primitives_installed = 0;


////////////////////////////////////////////////////////////////////////////////
/// Do some checks at the start of each primitives function.
///
/// \param calling_function Name the function that calls 
/// for this check or installation.
///
/// Checks whether the primitives subsystem is installed. 
/// If not, the primitives subsystem is installed.
///
/// Checks whether the drawing target is set. If not, the program is aborted.
////////////////////////////////////////////////////////////////////////////////
void ts5_check_primitives(char *calling_function)
{
	ts5_log(TS5_LOGLEVEL_6, "%s: ts5_check_primitives\n", calling_function);

	if (!_ts5_is_primitives_installed) {
		ts5_install_primitives(calling_function);
	}

	if (!_ts5_data.target) {
		ts5_fatal("%s: no drawing target specified\n", calling_function);
	}
}


////////////////////////////////////////////////////////////////////////////////
/// Install the primitives drawing subsystem.
///
/// \param calling_function Name the function that calls 
/// for this check or installation.
///
/// This function is called automatically if necessary.
////////////////////////////////////////////////////////////////////////////////
void ts5_install_primitives(char *calling_function)
{
	if (!_ts5_is_tscope5_installed) {
		ts5_install_tscope5(calling_function);
	}

	if (!_ts5_is_primitives_installed) {

		_ts5_is_primitives_installed = 1;
		ts5_log(TS5_LOGLEVEL_1, "%s: Installing Tscope5 primitives\n", 
				calling_function);

		if (!al_init_primitives_addon()) {
			ts5_fatal("%s: could not install Tscope5 primitives\n", 
					calling_function);
		}

		atexit(ts5_uninstall_primitives);
	}
}


////////////////////////////////////////////////////////////////////////////////
/// Uninstall the primitives drawing subsystem.
///
/// This function is called automatically at the end of the program.
////////////////////////////////////////////////////////////////////////////////
void ts5_uninstall_primitives()
{
	if (_ts5_is_primitives_installed) {

		ts5_log(TS5_LOGLEVEL_1, "Uninstalling Tscope5 primitives\n");

		// al_shutdown_primitives_addon();

		_ts5_is_primitives_installed = 0;
	}
}

